@@ -17,23 +17,21 @@ from pyiqoptionapi.http.buyback import Buyback
 from pyiqoptionapi.http.changebalance import Changebalance
 from pyiqoptionapi.http.events import Events
 from pyiqoptionapi.ws.client import WebsocketClient
-from pyiqoptionapi.ws.chanels.get_balance import *
-
-# from pyiqoptionapi.ws.chanels.ssid import Ssid
-# from pyiqoptionapi.ws.chanels.subscribe import *
-# from pyiqoptionapi.ws.chanels.unsubscribe import *
-# from pyiqoptionapi.ws.chanels.setactives import SetActives
-from pyiqoptionapi.ws.chanels import *
+from pyiqoptionapi.ws.chanels.get_balances import *
 
+from pyiqoptionapi.ws.chanels.ssid import Ssid
+from pyiqoptionapi.ws.chanels.subscribe import *
+from pyiqoptionapi.ws.chanels.unsubscribe import *
+from pyiqoptionapi.ws.chanels.setactives import SetActives
 from pyiqoptionapi.ws.chanels.candles import GetCandles
 from pyiqoptionapi.ws.chanels.buyv2 import Buyv2
 from pyiqoptionapi.ws.chanels.buyv3 import *
 from pyiqoptionapi.ws.chanels.user import *
-from pyiqoptionapi.ws.chanels.api_game_betinfo import GameBetInfo
+from pyiqoptionapi.ws.chanels.api_game_betinfo import Game_betinfo
 from pyiqoptionapi.ws.chanels.instruments import Get_instruments
 from pyiqoptionapi.ws.chanels.get_financial_information import GetFinancialInformation
-from pyiqoptionapi.ws.chanels.strike_list import StrikeList
-from pyiqoptionapi.ws.chanels.leaderboard import LeaderBoard
+from pyiqoptionapi.ws.chanels.strike_list import Strike_list
+from pyiqoptionapi.ws.chanels.leaderboard import Leader_Board
 
 from pyiqoptionapi.ws.chanels.traders_mood import Traders_mood_subscribe
 from pyiqoptionapi.ws.chanels.traders_mood import Traders_mood_unsubscribe
@@ -51,7 +49,7 @@ from pyiqoptionapi.ws.chanels.heartbeat import Heartbeat
  
 from pyiqoptionapi.ws.chanels.digital_option import *
 from pyiqoptionapi.ws.chanels.api_game_getoptions import *
-from pyiqoptionapi.ws.chanels.sell_option import SellOption
+from pyiqoptionapi.ws.chanels.sell_option import Sell_Option
 from pyiqoptionapi.ws.chanels.change_tpsl import Change_Tpsl
 from pyiqoptionapi.ws.chanels.change_auto_margin_call import ChangeAutoMarginCall
 
@@ -61,28 +59,31 @@ from pyiqoptionapi.ws.objects.candles import Candles
 from pyiqoptionapi.ws.objects.listinfodata import ListInfoData
 from pyiqoptionapi.ws.objects.betinfo import GameBetInfoData
 
-from pyiqoptionapi.ws.objects import *
-
 from pyiqoptionapi.helpers.global_value import Globals
 import pyiqoptionapi.helpers.constants as OP_code
-from pyiqoptionapi.helpers.countries import Countries
-from pyiqoptionapi.helpers.utils import nested_dict
 
 from collections import defaultdict
 
 import threading
 
+
+def nested_dict(n, type_dict):
+    if n == 1:
+        return defaultdict(type_dict)
+    else:
+        return defaultdict(lambda: nested_dict(n-1, type_dict))
+
 # InsecureRequestWarning: Unverified HTTPS request is being made.
 # Adding certificate verification is strongly advised.
 # See: https://urllib3.readthedocs.org/en/latest/security.html
-requests.packages.urllib3.disable_warnings()
+requests.packages.urllib3.disable_warnings()  # pylint: disable=no-member
 
 
 class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
     """Class for communication with IQ Option API."""
     
     ######################################################################
-    socket_option_opened = {}
+    socket_option_opened={}
     lock_socket_option_opened = threading.RLock()
     ######################################################################
 
@@ -98,8 +99,6 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
     #####################################################################
     api_option_init_all_result = []
     api_option_init_all_result_v2 = []
-    instrument_data_binary = []
-    instrument_data_turbo = []
     lock_option_init_all_result = threading.RLock()
     #####################################################################
 
@@ -178,11 +177,6 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
     lock_position_history = threading.RLock()
     ######################################################################
 
-    ######################################################################
-    position_history_v3 = None
-    lock_position_history_v3 = threading.RLock()
-    ######################################################################
-
     ######################################################################
     available_leverages = None
     lock_leverage = threading.RLock()
@@ -211,9 +205,6 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
 
     ######################################################################
     live_deal_data = nested_dict(3, deque)
-    live_deal_data_binary = LiveDeals()
-    live_deal_data_turbo = LiveDeals()
-    live_deal_data_digital = LiveDeals()
     lock_live_deal_data = threading.RLock()
     ######################################################################
 
@@ -252,12 +243,12 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
     ######################################################################
 
     ######################################################################
-    top_assets_updated_data = {}
+    top_assets_updated_data={}
     lock_top_assets_updated = threading.RLock()
     ######################################################################
 
     ######################################################################
-    get_options_v2_data = None
+    get_options_v2_data=None
     lock_get_options_v2 = threading.RLock()
     ######################################################################
 
@@ -290,7 +281,7 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
     ######################################################################
 
     ######################################################################
-    users_availability = None
+    users_availability=None
     lock_users_availability = threading.RLock()
     ######################################################################
 
@@ -314,7 +305,6 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
         self.password = password
         self.proxies = proxies
         self.lock_actives = threading.RLock()
-        self.countries = Countries(self)
         # is used to determine if a buyOrder was set  or failed. If
         # it is None, there had been no buy order yet or just send.
         # If it is false, the last failed
@@ -361,8 +351,7 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
         logger = logging.getLogger(__name__)
         url = self.prepare_http_url(resource)
         logger.debug(url)
-        response = self.session.request(method=method, url=url, data=data, params=params, headers=headers,
-                                        proxies=self.proxies)
+        response = self.session.request(method=method, url=url, data=data, params=params, headers=headers, proxies=self.proxies)
         logger.debug(response)
         logger.debug(response.text)
         logger.debug(response.headers)
@@ -383,8 +372,7 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
         logger = logging.getLogger(__name__)
         logger.debug(method+": "+url+" headers: " + str(self.session.headers)+" cookies: " +
                      str(self.session.cookies.get_dict()))
-        response = self.session.request(method=method, url=url, data=data, params=params, headers=headers,
-                                        proxies=self.proxies)
+        response = self.session.request(method=method, url=url, data=data, params=params, headers=headers, proxies=self.proxies)
         logger.debug(response)
         logger.debug(response.text)
         logger.debug(response.headers)
@@ -400,17 +388,17 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
         """
         return self.websocket_client.wss
 
-    def send_websocket_request(self, name, msg, request_id="", no_force_send=True):
+    def send_websocket_request(self, name, msg, request_id="",no_force_send=True):
         """Send websocket request to IQ Option server.
         :param str name: The websocket request name.
         :param dict msg: The websocket request msg.
         """
         logger = logging.getLogger(__name__)
         data = json.dumps(dict(name=name, msg=msg, request_id=request_id))
-        while (self.global_value.ssl_Mutual_exclusion or self.global_value.ssl_Mutual_exclusion_write) \
-                and no_force_send:
+        while (self.global_value.ssl_Mutual_exclusion or self.global_value.ssl_Mutual_exclusion_write) and no_force_send:
             pass
         self.global_value.ssl_Mutual_exclusion_write = True
+        #time.sleep(.2)
         self.websocket.send(data)
         logger.debug(data)
         self.global_value.ssl_Mutual_exclusion_write = False
@@ -531,7 +519,7 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
         :returns: The instance of :class:`Login
             <iqoptionapi.http.getprofile.Getprofile>`.
         """
-        return GetBalance(self)
+        return Get_Balances(self)
 
     @property
     def get_instruments(self):
@@ -553,11 +541,11 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
 # --------------------------------------------------------------------------------
     @property
     def Subscribe_Live_Deal(self):
-        return SubscribeLiveDeal(self)
+        return Subscribe_live_deal(self)
 
     @property
     def Unscribe_Live_Deal(self):
-        return UnscribeLiveDeal(self)
+        return Unscribe_live_deal(self)
 # --------------------------------------------------------------------------------
 # trader mood
 
@@ -584,7 +572,7 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
 
     @property
     def subscribe_all_size(self):
-        return SubscribeCandles(self)
+        return Subscribe_candles(self)
 
     @property
     def unsubscribe(self):
@@ -597,7 +585,7 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
 
     @property
     def unsubscribe_all_size(self):
-        return UnsubscribeCandles(self)
+        return Unsubscribe_candles(self)
 
     def portfolio(self, Main_Name, name, instrument_type, user_balance_id="", limit=1, offset=0, request_id=""):
         #Main name:"unsubscribeMessage"/"subscribeMessage"/"sendMessage"(only for portfolio.get-positions")
@@ -675,19 +663,19 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
     
     @property
     def Subscribe_Top_Assets_Updated(self):
-        return SubscribeTopAssetsUpdated(self)
+        return Subscribe_top_assets_updated(self)
 
     @property
     def Unsubscribe_Top_Assets_Updated(self):
-        return UnsubscribeTopAssetsUpdated(self)
+        return Unsubscribe_top_assets_updated(self)
 
     @property
     def Subscribe_Commission_Changed(self):
-        return SubscribeCommissionChanged(self)
+        return Subscribe_commission_changed(self)
 
     @property
     def Unsubscribe_Commission_Changed(self):
-        return UnsubscribeCommissionChanged(self)
+        return Unsubscribe_commission_changed(self)
         
 # --------------------------------------------------------------------------------
 # -----------------------------------------------------------------------------------
@@ -703,7 +691,7 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
     
     @property
     def Get_Leader_Board(self):
-        return LeaderBoard(self)
+        return Leader_Board(self)
     
     @property
     def getcandles(self):
@@ -718,14 +706,17 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
         self.send_websocket_request(name="api_option_init_all", msg="")
 
     def get_api_option_init_all_v2(self):
-        msg = {"name": "get-initialization-data", "version": "3.0", "body": {}}
+     
+        msg={"name": "get-initialization-data",
+                                    "version": "3.0",
+                                    "body": {}
+                                    }
         self.send_websocket_request(name="sendMessage", msg=msg)
-
 # -------------get information-------------
 
     @property
     def get_betinfo(self):
-        return GameBetInfo(self)
+        return Game_betinfo(self)
 
     @property
     def get_options(self):
@@ -758,27 +749,27 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
 
     @property
     def sell_option(self):
-        return SellOption(self)
+        return Sell_Option(self)
 # ____________________for_______digital____________________
 
     def get_digital_underlying(self):
-        msg = {"name": "get-underlying-list",
-               "version": "2.0",
-               "body": {"type": "digital-option"}
-              }
-        self.send_websocket_request(name="sendMessage", msg=msg)
+        msg={"name": "get-underlying-list",
+                                    "version": "2.0",
+                                    "body": {"type": "digital-option"}
+                                    }
+        self.send_websocket_request(name="sendMessage",msg=msg)
 
     @property
     def get_strike_list(self):
-        return StrikeList(self)
+        return Strike_list(self)
 
     @property
     def subscribe_instrument_quites_generated(self):
-        return SubscribeInstrumentQuitesGenerated(self)
+        return Subscribe_Instrument_Quites_Generated(self)
 
     @property
     def unsubscribe_instrument_quites_generated(self):
-        return UnsubscribeInstrumentQuitesGenerated(self)
+        return Unsubscribe_Instrument_Quites_Generated(self)
 
     @property
     def place_digital_option(self):
@@ -829,10 +820,6 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
     def get_position_history_v2(self):
         return Get_position_history_v2(self)
 
-    @property
-    def get_position_history_v3(self):
-        return Get_position_history_v3(self)
-
     @property
     def get_available_leverages(self):
         return Get_available_leverages(self)
@@ -874,7 +861,7 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
                                                                          "ca_certs": "cacert.pem"
                                                                         }
                                                             }
-                                                     )
+                                                     )  # for fix pyinstall error: cafile, capath and cadata cannot be all omitted
             self.websocket_thread.daemon = True
             self.websocket_thread.start()
         except Exception as exception:
@@ -960,8 +947,11 @@ class IQOptionAPI(object):  # pylint: disable=too-many-instance-attributes
         return True, None
 
     def close(self):
-        self.websocket.close()
-        self.websocket_thread.join(1)
+        try:
+            self.websocket.close()
+            self.websocket_thread.join(1)
+        except Exception as exception:
+            logging.error('close-conection-socket: {}'.format(exception))
 
     def websocket_alive(self):
         return self.websocket_thread.is_alive()
