@@ -3,7 +3,7 @@ from pyiqoptionapi.ws.chanels.base import Base
 import logging
 
 
-class GameBetInfo(Base):
+class Game_betinfo(Base):
 
     name = "api_game_betinfo"
 
@@ -15,7 +15,7 @@ class GameBetInfo(Base):
             for idx, val in enumerate(id_number_list):
                 data["id["+str(idx)+"]"] = int(val)
         elif id_number_list is None:
-            raise ValueError('**error** GameBetInfo can not input None type, please input buy id')
+            logging.error('**error** Game_betinfo can not input None type, please input buy id')
         else:
             data["id[0]"] = int(id_number_list)
 
