@@ -88,7 +88,7 @@ class WebsocketClient(object):
             active_id = message["msg"]["active_id"]
             Active_name = list(actives.keys())[list(actives.values()).index(active_id)]
             commission = message["msg"]["commission"]["value"]
-            with self.api.lock_subscribe_commission:
+            with self.api.lock_live_deal_data:
                 self.api.subscribe_commission_changed_data[instrument_type][Active_name][self.api.timesync.server_timestamp] = int(commission)
             
         #######################################################
@@ -173,14 +173,14 @@ class WebsocketClient(object):
             with self.api.lock_option_init_all_result:
                 self.api.api_option_init_all_result_v2 = message["msg"]
         elif message["name"] == "underlying-list":
-            with self.api.lock_underlying_list:
-                self.api.underlying_list_data = message["msg"]
+            with self.api.lock:
+                self.api.underlying_list_data=message["msg"]
         elif message["name"] == "instruments":
             with self.api.lock_instruments:
-                self.api.instruments = message["msg"]
+                self.api.instruments=message["msg"]
         elif message["name"] == "financial-information":
             with self.api.lock_financial_info:
-                self.api.financial_information = message
+                self.api.financial_information=message
         elif message["name"] == "position-changed":
             if message["microserviceName"] == "portfolio" and (message["msg"]["source"] == "digital-options") \
                     or message["msg"]["source"] == "trading":
@@ -196,7 +196,7 @@ class WebsocketClient(object):
             with self.api.lock_position_change:
                 self.api.order_async[int(message["msg"]["option_id"])][message["name"]] = message
         elif message["name"] == "top-assets-updated":
-            with self.api.lock_top_assets_updated:
+            with self.api.lock_auto_margin_call_changed:
                 self.api.top_assets_updated_data[str(message["msg"]["instrument_type"])] = message["msg"]["data"]
         elif message["name"] == "strike-list":
             with self.api.lock_strike_list:
@@ -205,12 +205,12 @@ class WebsocketClient(object):
             self.api.game_betinfo.process_message(message["msg"])
             #self.api.game_betinfo.isSuccessful = message["msg"]["isSuccessful"]
             #self.api.game_betinfo.dict = message["msg"]
-        elif message["name"] == "traders-mood-changed":
+        elif message["name"]=="traders-mood-changed":
             with self.api.lock_mood:
-                self.api.traders_mood[message["msg"]["asset_id"]] = message["msg"]["value"]
+                self.api.traders_mood[message["msg"]["asset_id"]]=message["msg"]["value"]
         #------for forex&cfd&crypto..
         elif message["name"] == "order-placed-temp":
-            with self.api.lock_buy_order_id:
+            with self.api.lock:
                 self.api.buy_order_id = message["msg"]["id"]
         elif message["name"] == "order":
             with self.api.lock_buy_order_id:
@@ -224,56 +224,49 @@ class WebsocketClient(object):
         elif message["name"] == "deferred-orders":
             with self.api.lock_deferred_orders:
                 self.api.deferred_orders = message
-        elif message["name"] == "position-history":
+        elif message["name"]=="position-history":
             with self.api.lock_position_history:
-                self.api.position_history = message
-        elif message["name"] == "history-positions":
-            if message['request_id'] == 'users_history_data':
-                with self.api.lock_position_history_v3:
-                    self.api.position_history_v3 = message
-            else:
-                with self.api.lock_position_history:
-                    self.api.position_history_v2 = message
-        elif message["name"] == "available-leverages":
+                self.api.position_history=message
+        elif message["name"]=="history-positions":
+            with self.api.lock_position_history:
+                self.api.position_history_v2=message
+        elif message["name"]=="available-leverages":
             with self.api.lock_leverage:
                 self.api.available_leverages=message
-        elif message["name"] == "order-canceled":
+        elif message["name"]=="order-canceled":
             with self.api.lock_order_canceled:
                 self.api.order_canceled=message
-        elif message["name"] == "position-closed":
+        elif message["name"]=="position-closed":
             with self.api.lock_close_position_data:
                 self.api.close_position_data=message
-        elif message["name"] == "overnight-fee":
+        elif message["name"]=="overnight-fee":
             with self.api.lock_overnight_fee:
                 self.api.overnight_fee=message
-        elif message["name"] == "api_game_getoptions_result":
+        elif message["name"]=="api_game_getoptions_result":
             with self.api.lock_api_game_getoptions:
                 self.api.api_game_getoptions_result=message
-        elif message["name"] == "sold-options":
+        elif message["name"]=="sold-options":
             with self.api.lock_sold_options_respond:
                 self.api.sold_options_respond=message
-        elif message["name"] == "tpsl-changed":
+        elif message["name"]=="tpsl-changed":
             with self.api.lock_tpsl_changed_respond:
                 self.api.tpsl_changed_respond=message
-        elif message["name"] == "position-changed":
+        elif message["name"]=="position-changed":
             with self.api.lock_position_change:
                 self.api.position_changed=message
-        elif message["name"] == "auto-margin-call-changed":
+        elif message["name"]=="auto-margin-call-changed":
             with self.api.lock_auto_margin_call_changed:
                 self.api.auto_margin_call_changed_respond=message
-        elif message["name"] == "digital-option-placed":
+        elif message["name"]=="digital-option-placed":
             try:
                 with self.api.lock_digital_option_placed_id:
-                    self.api.digital_option_placed_id = message["msg"]["id"]
+                    self.api.digital_option_placed_id=message["msg"]["id"]
             except:
                 with self.api.lock_digital_option_placed_id:
-                    self.api.digital_option_placed_id = message["msg"]
-        elif message["name"] == "result":
+                    self.api.digital_option_placed_id=message["msg"]
+        elif message["name"]=="result":
             with self.api.lock_buy_multi:
-                self.api.result = message["msg"]["success"]
-        elif message['name'] == "expiration-list-changed":
-            print(message['name']['msg'])
-            pass
+                self.api.result=message["msg"]["success"]
         elif message["name"] == "instrument-quotes-generated":
             actives = self.api.actives
             Active_name = list(actives.keys())[list(actives.values()).index(message["msg"]["active"])]
@@ -286,7 +279,7 @@ class WebsocketClient(object):
                     ProfitPercent = None
                 else:
                     askPrice = (float)(data["price"]["ask"])
-                    ProfitPercent = ((100 - askPrice) * 100) / askPrice
+                    ProfitPercent = ((100-askPrice)*100)/askPrice
                 
                 for symble in data["symbols"]:
                     try:
@@ -304,35 +297,31 @@ class WebsocketClient(object):
         elif message["name"] == "training-balance-reset":
             with self.api.lock_training_balance_reset:
                 self.api.training_balance_reset_request=message["msg"]["isSuccessful"]
-
-        ########################################################################################################
-        # Processing Live Deals Data
-        ########################################################################################################
-
         elif message["name"] == "live-deal-binary-option-placed":
+            name=message["name"]
+            active_id=message["msg"]["active_id"]
+            actives = self.api.actives
+            active = list(actives.keys())[list(actives.values()).index(active_id)]
+            _type = message["msg"]["option_type"]
             try:
-                type_active = message["msg"]["option_type"]
-                if type_active == "turbo":
-                    self.api.live_deal_data_turbo.set_live_deals(message["msg"])
-                else:
-                    self.api.live_deal_data_binary.set_live_deals(message["msg"])
-            except KeyError:
-                logging.error('live-deal-binary-option-placed -> key invalid -> {}'.format(message["msg"]))
+                with self.api.lock_live_deal_data:
+                    self.api.live_deal_data[name][active][_type].appendleft(message["msg"])
+            except Exception as exception:
+                logging.error("live-deal-binary-option-placed: {}".format(exception))
         elif message["name"] == "live-deal-digital-option":
+            name = message["name"]
+            active_id = message["msg"]["instrument_active_id"]
+            actives = self.api.actives
+            active = list(actives.keys())[list(actives.values()).index(active_id)]
+            _type = message["msg"]["expiration_type"]
             try:
-                self.api.live_deal_data_digital.set_live_deals(message["msg"])
-            except KeyError:
-                logging.error('live-deal-digital-option -> key invalid -> {}'.format(message["msg"]))
-            # name = message["name"]
-            # active_id = message["msg"]["instrument_active_id"]
-            # actives = self.api.actives
-            # active = list(actives.keys())[list(actives.values()).index(active_id)]
-            # _type = message["msg"]["expiration_type"]
-            # try:
-            #     with self.api.lock_live_deal_data:
-            #         self.api.live_deal_data[name][active][_type].appendleft(message["msg"])
-            # except Exception as exception:
-            #     logging.error("live-deal-digital-option:{}".format(exception))
+                with self.api.lock_live_deal_data:
+                    self.api.live_deal_data[name][active][_type].appendleft(message["msg"])
+            except Exception as exception:
+                logging.error("live-deal-digital-option:{}".format(exception))
+        elif message["name"] == "leaderboard-deals-client":
+            with self.api.lock_leaderbord_deals_client:
+                self.api.leaderboard_deals_client = message["msg"]
         elif message["name"] == "live-deal":
             name = message["name"]
             active_id = message["msg"]["instrument_active_id"]
@@ -344,10 +333,6 @@ class WebsocketClient(object):
                     self.api.live_deal_data[name][active][_type].appendleft(message["msg"])
             except Exception as exception:
                 logging.error("live-deal: {}".format(exception))
-
-        elif message["name"] == "leaderboard-deals-client":
-            with self.api.lock_leaderbord_deals_client:
-                self.api.leaderboard_deals_client = message["msg"]
         elif message["name"] == "user-profile-client":
             with self.api.lock_user_profile_client:
                 self.api.user_profile_client = message["msg"]
